pub enum Error {
Syntax(Error),
CompiledTooBig(Error),
Match(String),
// some variants omitted
}Expand description
Represents all the ways that StringRegex can fail.
This type is not intended to be exhaustively matched, and new variants may be added in the future without a major version bump.
Variants
Syntax(Error)
A syntax error.
CompiledTooBig(Error)
The compiled program exceeded the set size limit. The argument is the size limit imposed.
Match(String)
The regex pattern did not match the provided StringRegex::input.
The contained string value is either a default mismatch error, or a
custom error, based on the StringRegex::mismatch_error value.